# wsi-server
Very simple wsi patching server

# installation
- install [openslide](https://openslide.org/download/)
  - e.g.: `apt-get install openslide-tools` (Ubuntu)
- `pip install git+https://github.com/tand826/wsiserver`

# run with example viewer
1. run `wsiserver [wsi path]`
2. open `example/index.html` in web browser